@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999-2014.
+ * Copyright (c) Tony Bybell 1999-2016.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -168,6 +168,73 @@ for(i=nbits-1;i>=0;i--) /* always requires less number of bits */
 }
 
 
+static void cvt_fpsdec(Trptr t, TimeType val, char *os, int len)
+{
+int shamt = t->t_fpdecshift;
+TimeType lpart = val >> shamt;
+TimeType rmsk = (1 << shamt);
+TimeType rbit = (val >= 0) ? (val & (rmsk-1)) : ((-val) & (rmsk-1));
+double rfrac;
+char dbuf[32];
+char bigbuf[64];
+
+if(rmsk)
+	{
+	rfrac = (double)rbit / (double)rmsk;
+	}
+	else
+	{
+	rfrac = 0.0;
+	}			
+
+sprintf(dbuf, "%.16g", rfrac);			
+char *dot = strchr(dbuf, '.');
+if(dot && (dbuf[0] == '0'))
+	{
+	sprintf(bigbuf, TTFormat".%s", lpart, dot+1);
+	strncpy(os, bigbuf, len);
+	os[len-1] = 0;
+	}
+	else
+	{
+	sprintf(os, TTFormat, lpart);
+	}
+}
+
+static void cvt_fpsudec(Trptr t, TimeType val, char *os, int len)
+{
+int shamt = t->t_fpdecshift;
+UTimeType lpart = ((UTimeType)val) >> shamt;
+TimeType rmsk = (1 << shamt);
+TimeType rbit = (val & (rmsk-1));
+double rfrac;
+char dbuf[32];
+char bigbuf[64];
+
+if(rmsk)
+	{
+	rfrac = (double)rbit / (double)rmsk;
+	}
+	else
+	{
+	rfrac = 0.0;
+	}			
+
+sprintf(dbuf, "%.16g", rfrac);			
+char *dot = strchr(dbuf, '.');
+if(dot && (dbuf[0] == '0'))
+	{
+	sprintf(bigbuf, UTTFormat".%s", lpart, dot+1);
+	strncpy(os, bigbuf, len);
+	os[len-1] = 0;
+	}
+	else
+	{
+	sprintf(os, UTTFormat, lpart);
+	}
+}
+
+
 /*
  * convert trptr+vptr into an ascii string
  */
@@ -294,11 +361,40 @@ if(flags&TR_ASCII)
 	char *parse;
 	int found=0;
 
+	free_2(newbuff);
+	newbuff=(char *)malloc_2(nbits+14); /* for justify */
+	if(flags&TR_REVERSE)
+		{
+		char *fwdpnt, *revpnt;
+	
+		fwdpnt=(char *)bits;
+		revpnt=newbuff+nbits+14;
+		for(i=0;i<7;i++) *(--revpnt)=xfwd[0];
+		for(i=0;i<nbits;i++)
+			{
+			*(--revpnt)=xtab[(int)(*(fwdpnt++))];
+			}
+		for(i=0;i<7;i++) *(--revpnt)=xfwd[0];
+		}
+		else
+		{
+		char *fwdpnt, *fwdpnt2;
+	
+		fwdpnt=(char *)bits;
+		fwdpnt2=newbuff;
+		for(i=0;i<7;i++) *(fwdpnt2++)=xfwd[0];
+		for(i=0;i<nbits;i++)
+			{
+			*(fwdpnt2++)=xtab[(int)(*(fwdpnt++))];
+			}
+		for(i=0;i<7;i++) *(fwdpnt2++)=xfwd[0];
+		}
+
 	len=(nbits/8)+2+2;		/* $xxxxx */
 	os=pnt=(char *)calloc_2(1,len);
 	if(GLOBALS->show_base) { *(pnt++)='"'; }
 
-	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+3)&3)):(newbuff+3);
+	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+7)&7)):(newbuff+7);
 	cvt_gray(flags,parse,nbits);
 
 	for(i=0;i<nbits;i+=8)
@@ -576,7 +672,14 @@ else if(flags&TR_SIGNED)
 
 	if(!fail)
 		{
-		sprintf(os, TTFormat, val);
+		if((flags&TR_FPDECSHIFT)&&(t->t_fpdecshift))
+			{
+			cvt_fpsdec(t, val, os, len);
+			}
+			else
+			{
+			sprintf(os, TTFormat, val);
+			}
 		}
 		else
 		{
@@ -655,7 +758,14 @@ else	/* decimal when all else fails */
 
 	if(!fail)
 		{
-		sprintf(os, UTTFormat, val);
+		if((flags&TR_FPDECSHIFT)&&(t->t_fpdecshift))
+			{
+			cvt_fpsudec(t, val, os, len);
+			}
+			else
+			{
+			sprintf(os, UTTFormat, val);
+			}
 		}
 		else
 		{
@@ -955,11 +1065,40 @@ if(flags&TR_ASCII)
 	char *parse;
 	int found=0;
 
+	free_2(newbuff);
+	newbuff=(char *)malloc_2(nbits+14); /* for justify */
+	if(flags&TR_REVERSE)
+		{
+		char *fwdpnt, *revpnt;
+	
+		fwdpnt=(char *)bits;
+		revpnt=newbuff+nbits+14;
+		for(i=0;i<7;i++) *(--revpnt)=xfwd[0];
+		for(i=0;i<nbits;i++)
+			{
+			*(--revpnt)=xtab[(int)(*(fwdpnt++))];
+			}
+		for(i=0;i<7;i++) *(--revpnt)=xfwd[0];
+		}
+		else
+		{
+		char *fwdpnt, *fwdpnt2;
+	
+		fwdpnt=(char *)bits;
+		fwdpnt2=newbuff;
+		for(i=0;i<7;i++) *(fwdpnt2++)=xfwd[0];
+		for(i=0;i<nbits;i++)
+			{
+			*(fwdpnt2++)=xtab[(int)(*(fwdpnt++))];
+			}
+		for(i=0;i<7;i++) *(fwdpnt2++)=xfwd[0];
+		}
+
 	len=(nbits/8)+2+2;		/* $xxxxx */
 	os=pnt=(char *)calloc_2(1,len);
 	if(GLOBALS->show_base) { *(pnt++)='"'; }
 
-	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+3)&3)):(newbuff+3);
+	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+7)&7)):(newbuff+7);
 	cvt_gray(flags,parse,nbits);
 
 	for(i=0;i<nbits;i+=8)
@@ -1235,7 +1374,14 @@ else if(flags&TR_SIGNED)
 
 	if(!fail)
 		{
-		sprintf(os, TTFormat, val);
+		if((flags&TR_FPDECSHIFT)&&(t->t_fpdecshift))
+			{
+			cvt_fpsdec(t, val, os, len);
+			}
+			else
+			{
+			sprintf(os, TTFormat, val);
+			}
 		}
 		else
 		{
@@ -1314,7 +1460,14 @@ else	/* decimal when all else fails */
 
 	if(!fail)
 		{
-		sprintf(os, UTTFormat, val);
+		if((flags&TR_FPDECSHIFT)&&(t->t_fpdecshift))
+			{
+			cvt_fpsudec(t, val, os, len);
+			}
+			else
+			{
+			sprintf(os, UTTFormat, val);
+			}
 		}
 		else
 		{
