@@ -162,6 +162,9 @@ WV_MENU_G2B,
 WV_MENU_GBNONE,
 WV_MENU_POPON,
 WV_MENU_POPOFF,
+WV_MENU_FPSHIFTON,
+WV_MENU_FPSHIFTOFF,
+WV_MENU_FPSHIFTVAL,
 WV_MENU_CLRFMT0,
 WV_MENU_CLRFMT1,
 WV_MENU_CLRFMT2,
