@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell and Concept Engineering GmbH 2008-2014.
+ * Copyright (c) Tony Bybell and Concept Engineering GmbH 2008-2016.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -896,6 +896,7 @@ match_type_list = calloc_2(c, sizeof(int *));
 most_recent_lbrack_list = calloc_2(c, sizeof(char *));
 
 GLOBALS->default_flags=TR_RJUSTIFY;
+GLOBALS->default_fpshift=0;
 
 GLOBALS->strace_current_window = 0; /* in case there are shadow traces; in reality this should never happen */
 
@@ -1214,6 +1215,7 @@ for(ii=0;ii<c;ii++)
 paste_routine:
 
 GLOBALS->default_flags=TR_RJUSTIFY;
+GLOBALS->default_fpshift=0;
 
 GLOBALS->traces.buffercount=GLOBALS->traces.total;
 GLOBALS->traces.buffer=GLOBALS->traces.first;
@@ -2046,6 +2048,12 @@ char *emit_gtkwave_savefile_formatted_entries_in_tcl_list(Trptr t, gboolean use_
 			WAVE_OE_ME
 			}
 
+		if(t->t_fpdecshift)
+			{
+			one_entry = make_message("[fpshift_count] %d\n", t->t_fpdecshift);
+			WAVE_OE_ME
+			}
+
 		if((t->shift)||((prevshift)&&(!t->shift)))
 			{
 			one_entry = make_message(">"TTFormat"\n", t->shift);
